#!/usr/bin/python

# To release a new version, tag it:
#   git tag -a nilmrun-1.1 -m "Version 1.1"
#   git push --tags
# Then just package it up:
#   python setup.py sdist

import sys
import os
from setuptools import setup

# Versioneer manages version numbers from git tags.
# https://github.com/warner/python-versioneer
import versioneer

# Get list of requirements to use in `install_requires` below.  Note
# that we don't make a distinction between things that are actually
# required for end-users vs developers (or use `test_requires` or
# anything else) -- just install everything for simplicity.
install_requires = open('requirements.txt').readlines()

# Run setup
setup(name='nilmrun',
      version = versioneer.get_version(),
      cmdclass = versioneer.get_cmdclass(),
      url = 'https://git.jim.sh/nilm/nilmrun.git',
      author = 'Jim Paris',
      description = "NILM Database Filter Runner",
      long_description = "NILM Database Filter Runner",
      license = "Proprietary",
      author_email = 'jim@jtan.com',
      install_requires = install_requires,
      packages = [ 'nilmrun',
                   'nilmrun.scripts',
                   ],
      package_dir = { 'nilmrun': 'nilmrun',
                      'nilmrun.scripts': 'scripts',
                      },
      entry_points = {
          'console_scripts': [
              'nilmrun-server = nilmrun.scripts.nilmrun_server:main',
              'nilmrun-ps = nilmrun.scripts.ps:main',
              'nilmrun-run = nilmrun.scripts.run:main',
              'nilmrun-kill = nilmrun.scripts.kill:main',
              ],
          },
      zip_safe = False,
      )
